#!/usr/bin/env python
'''
Created on 13Nov2018
@author: Jaime A. Graulau

This script generates the flow data for the transects defined by the PSRP SWPF Enviromental Sub-team.
The configuration file for the transects contain the i,j locations for the cells for each transect.

The syntax to run the script in a Windows "cmd" window is:

    python TransectFlows.py Configfile.txt TansectOutFile.csv path *.*.xxx

where:
    Configfile.txt =  configuration file containing the cell name and i j indexes
                      of the cells to extract the times series
    TransectOutFile.csv = output file to store the data.
    path = path containing the output raster maps from GSSHA
    *.*.xxx = extension of the raster files to process

The output is a comma-delimited file that can be openend in Excel for post-processing the time series data.
Example:

	python TransectFlows.py CellIJs.txt MyOutput.csv ./CummFlowFolder *.*.asc

Author:
J. Graulau
Interagecy Modeling Section

Last revised:
Nov. 2018
'''

import linecache, os, fnmatch
import sys
import pandas as pd
import numpy as np

try:
	fin = open(sys.argv[1], 'r')
	fin.readline()
except:
	IOError, (errno,strerror)
	print("I/O error(%s): %s" % (errno, strerror))

try:
	fout = open(sys.argv[2], 'wt')
except:
	IOError, (errno, strerror)
	print("I/O error(%s): %s" % (errno, strerror))

try:
	hydro=[]
	for lines in fin.readlines():
		hydro.append([])
		station+=1
		HWMline = lines.strip().split()
		#print(HWMline)
		HWMname = HWMline[0]
		stanames[0].append(HWMname)
		iindex = int(HWMline[1])
		jindex = int(HWMline[2])
	print("Done with reading files loop.  Building the daily flow matrix for transects")
	print("This takes some time... please wait!!!")
	for i in range(0, len(zip(*hydro))):
		if i==0:
			row0=[float(x)/86400 for x in (zip(*hydro)[i])]
			Diff.append(np.asarray(row0))
		else:
			row1=[float(x)/86400 for x in (zip(*hydro)[i])]
			row2=[float(x)/86400 for x in (zip(*hydro)[i-1])]
			Diff.append(np.subtract(row1,row2))
	print("Done building the flow matrix....")
	Diff=np.asarray(Diff)
	# Compute Transect Flows, accumulate monthly, and convert to 
	# kac-ft/mth.  Save all values to the output file 
	print("Working on Transect N1")
	N1=np.sum(Diff[:,0:6],axis=1,keepdims=False)
	DtRng=pd.date_range('11/1/2003', '10/31/2013', freq='D')
	#This line is for debugging the data frame with only two transects.
	#Trans=pd.DataFrame(data={'N1':N1,'N2':N2}, columns=['N1','N2'],index=DtRng)
	Trans=pd.DataFrame(data={'N1':N1},columns=['N1'],index=DtRng)
	MthValues=Trans.groupby([lambda x: x.month]).sum()
	MthValues=MthValues*0.070046
	#This next commented line is to output daily cummulative transect flow data for debugging purposes
	#Trans.to_csv(fout,index=True,index_label='Date', float_format='%6.4f')
	#The next line saves the ouput transect flow data set to the specified output file
	MthValues.to_csv(fout,index=True,index_label='Month', float_format='%5.4f')
	print("Done!!! Check the contents of %s" % (sys.argv[2]))
except:
	print('Usage: TransectFlows.py <ConfigFile.txt> <output.csv> <path> <filext>')
	print('       where:') 
	print('              ConfigFile.txt : Configuration files with cells indexes (i,j)')
	print('                  output.csv : file name to output time series') 
	print('                        path : path where the GSSHA maps are stored')
	print('                      filext : extension of filenames in "path" directory')
	print('E.g. python TransectFlows.py CellIJs.txt CellHydro.csv ./DepthGrids *.*.asc')
	print('')
	sys.exit()

fin.close()
fout.close()
