#!/usr/bin/env python
'''
Created on 12Feb2019
@author: Jaime A. Graulau

This script generates a daily time series from a 15-min flow time series data in GSSHA for 
a selected number of stations as specified in the GSSHA.ihg file.

It also generates a summary file for storm events based on a series of dates on which rainfall/runoff
events are recorded.

The syntax to run the script in a linux promt is:

    python 15minTimeSeries.in EventDates.dat

where:
    15minTimeSeries.in =  GSSHA 15min interval time series output flow file
    1DayTimeSeries.out = Output daily flow time series. 

Last revised:
12Feb2019
'''

import linecache, os, fnmatch
import sys
import pandas as pd

if __debug__:
	print('Debug On')
else:
	print('Debug Off')

'Create an epock for date/time conversion'

epoch = pd.to_datetime(0, unit='s').to_julian_date()

try:
	fin1 = open(sys.argv[1], 'r')
	fout1 = open(sys.argv[2], 'wt')
	df=pd.read_csv(fin1, sep='\s+', header=None)
	df=df.set_index(0)
	df=df.set_index(pd.to_datetime(df.index-epoch, unit='D'))
	df.index=df.index.round('15min')
	df.columns=['Outlet', '63510', '55800', '55500', '66460', '73495', \
	'73360', '75800', '77500', '72100', '71760', '73300', '65000', \
        '59300', '575000', '71900', '585000', '58600']
	#df.to_csv('junk.csv', sep=',', index=True, index_label='Date', header=True, float_format='%.4f')
except:
	IOError, (errno,strerror)
	print("I/O error(%s): %s" % (errno, strerror))

try:
	QDaily=df.resample('3H').mean()*3*60*60
	QDaily.columns=['outlet', '63510', '55800', '55500', '66460', '73495', \
	'73360', '75800', '77500', '72100', '71760', '73300', '65000', \
        '59300', '575000', '71900', '585000', '58600']
	QDaily.to_csv(fout1, sep=',', index=True, index_label='Date', header=True, float_format='%.4f')
except:
	IOError, (errno, strerror)
	print("I/O error(%s): %s" % (errno, strerror))
	sys.exit()

fin1.close()
fout1.close()
