#!/usr/bin/env python
'''
Created on 23Aug2021
@author: Jaime A. Graulau

This script generates a daily time series from a 15-min lake time series data in GSSHA for 
a selected Lake.

The syntax to run the script in a linux promt is:

    python Stage15min2Day.py GSSHA.lal LakeDate.dat

where:
    GSSHA.lal =  GSSHA 15min interval time series lake stage output file
    LakeStage.dat = Output lake stage time series. 

Last revised:
23Aug2021
'''

import linecache, os, fnmatch
import sys
import pandas as pd

if __debug__:
	print('Debug On')
else:
	print('Debug Off')

try:
	fin = open(sys.argv[1], 'r')
	fout = open(sys.argv[2], 'wt')
	df=pd.read_csv(fin, sep='\s+', header=None)
	df.columns=['year', 'month', 'day', 'hour', 'minute', 'Lel', 'Lvol']
	df=df.set_index(pd.to_datetime(df[['year', 'month', 'day', 'hour', 'minute']]))
	df=df.drop(['year', 'month', 'day', 'hour', 'minute'], axis=1)
	#df.to_csv('junk.csv', sep=',', index=True, index_label='Date', header=True, float_format='%.4f')
except:
	IOError, (errno,strerror)
	print("I/O error(%s): %s" % (errno, strerror))

try:
	QDaily=df.resample('3H').mean()
        QDaily['LVoldiff']=QDaily['Lvol']-QDaily['Lvol'].shift(1)
	QDaily.to_csv(fout, sep=',', index=True, index_label='Date', header=True, float_format='%.4f')
except:
	IOError, (errno, strerror)
	print("I/O error(%s): %s" % (errno, strerror))
	sys.exit()

fin.close()
fout.close()
